(back-into orig noob)Puts the contents of noob into a collection of the same type as orig.
Puts the contents of `noob` into a collection of the same type as `orig`.
(cleanse-arglist arglist)Clear out pre-condtions and tags.
Clear out pre-condtions and tags.
(mk-positionalble-src-logging-push-back-rdr s file line col)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |