The query DSL: a small zipper-based language for selecting nodes out of a recorded call tree - by function name, call id, tag, source position or ancestry - and returning the matches with their surrounding context.
The query DSL: a small zipper-based language for selecting nodes out of a recorded call tree - by function name, call id, tag, source position or ancestry - and returning the matches with their surrounding context.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |