(save! item shelf slot-kw mk-ex-msg-fn & [prep])Shelve ITEM's value under its SLOT-KW slot in namespace SHELF. PREP, when given, transforms the value before it's stored - the workspace shelf uses this to store an independent snapshot rather than a live, still-mutating value.
Shelve ITEM's value under its SLOT-KW slot in namespace SHELF. PREP, when given, transforms the value before it's stored - the workspace shelf uses this to store an independent snapshot rather than a live, still-mutating value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |