Clojure only.

sayid.util.find-ns

Helpers for discovering loaded namespaces by name or wildcard pattern, used by the trace-by-pattern operations.

Helpers for discovering loaded namespaces by name or wildcard pattern, used by
the trace-by-pattern operations.
raw docstring

search-nsesclj

(search-nses q ref-ns)
source

cljdoc builds & hosts documentation for Clojure/Script libraries