Helpers for locating and reading the source of a function, used by inner tracing to recover the form it needs to instrument.
Helpers for locating and reading the source of a function, used by inner tracing to recover the form it needs to instrument.
(mk-positionalble-src-logging-push-back-rdr s file line col)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |